'use client';

import React, { useCallback, useState } from 'react';
import { Button, List } from 'antd';
import { useSearchParams } from 'next/navigation';
import { Filter } from '../../types/experts';
import { SearchData, Tag } from '../../types/tags';
import { useRouter } from '../../navigation';
import { getObjectByFilter, getObjectByAdditionalFilter } from '../../utils/filter';
import { CustomSwitch, CustomSlider } from '../view';

type ExpertsFilterProps = {
    searchData?: SearchData;
    basePath: string;
    priceTitle: string;
    durationTitle: string;
    buttonApply: string;
};

export const ExpertsFilter = ({
    searchData,
    basePath,
    priceTitle,
    durationTitle,
    buttonApply
}: ExpertsFilterProps) => {
    const searchParams = useSearchParams();
    const router = useRouter();
    const [filter, setFilter] = useState<Filter | undefined>(getObjectByFilter(searchParams));

    const onChangeTags = useCallback((id: number, checked: boolean) => {
        let themesTagIds = filter?.themesTagIds || [];

        if (checked && !themesTagIds?.includes(id)) {
            themesTagIds.push(id);
        }

        if (!checked && themesTagIds?.includes(id)) {
            themesTagIds = themesTagIds.filter((tId) => tId != id);
        }

        setFilter({
            ...filter,
            themesTagIds
        });
    }, [filter, searchParams, searchData]);

    const onChangePrice = useCallback(([min, max]: number[]) => {
        const newFilter: Filter = {
            ...filter,
            priceFrom: min,
            priceTo: max
        };

        if (newFilter.priceFrom === searchData?.sessionCostMin) {
            delete newFilter.priceFrom;
        }

        if (newFilter.priceTo === searchData?.sessionCostMax) {
            delete newFilter.priceTo;
        }

        setFilter(newFilter);
    }, [filter, searchParams, searchData]);

    const onChangeDuration = useCallback(([min, max]: number[]) => {
        const newFilter: Filter = {
            ...filter,
            durationFrom: min,
            durationTo: max
        };

        if (newFilter.durationFrom === searchData?.sessionDurationMin) {
            delete newFilter.durationFrom;
        }

        if (newFilter.durationTo === searchData?.sessionDurationMax) {
            delete newFilter.durationTo;
        }

        setFilter(newFilter);
    }, [filter, searchParams, searchData]);

    const goToFilterPage = useCallback(() => {
        router.push({
            pathname: basePath as any,
            query: {
                ...filter,
                ...getObjectByAdditionalFilter(searchParams)
            }
        })
    }, [filter, searchParams, searchData]);

    const getList = useCallback((data: Tag[]) => (
        <div className="b-filter__inner">
            <List
                itemLayout="vertical"
                size="small"
                dataSource={data}
                split={false}
                style={{ width: '100%' }}
                renderItem={({ id, name }) => (
                    <List.Item key={id} style={{ padding: 0 }}>
                        <div className="b-filter__item">
                            <div className="b-filter__title">{name}</div>
                            <CustomSwitch
                                defaultChecked={filter?.themesTagIds?.includes(id) || false}
                                onChange={(checked: boolean) => onChangeTags(id, checked)}
                            />
                        </div>
                    </List.Item>
                )}
            />
        </div>
    ), [filter, searchParams, searchData]);

    return (
        <div className="b-filter">
            {searchData?.themesGroups?.length && searchData.themesGroups.map(({ id, name, tags }) => (
                <div key={id}>
                    <h3 className="title-h3">{name}</h3>
                    {getList(tags)}
                </div>
            ))}
            <h3 className="title-h3">{priceTitle}</h3>
            <div className="b-filter__slider">
                <CustomSlider
                    range
                    step={1}
                    defaultValue={[filter?.priceFrom || searchData?.sessionCostMin || 0, filter?.priceTo || searchData?.sessionCostMax || 0]}
                    min={searchData?.sessionCostMin || 0}
                    max={searchData?.sessionCostMax || 0}
                    onChange={onChangePrice}
                />
            </div>
            <h3 className="title-h3">{durationTitle}</h3>
            <div className="b-filter__slider">
                <CustomSlider
                    range
                    step={1}
                    defaultValue={[filter?.durationFrom || searchData?.sessionDurationMin || 0, filter?.durationTo || searchData?.sessionDurationMax || 0]}
                    min={searchData?.sessionDurationMin || 0}
                    max={searchData?.sessionDurationMax || 0}
                    onChange={onChangeDuration}
                />
            </div>
            <Button
                className="btn-apply"
                onClick={goToFilterPage}
            >
                {buttonApply}
            </Button>
        </div>
    );
};
