'use client';

import React, { FC, useState } from 'react';
import { usePathname } from 'next/navigation';
import Image from 'next/image';
import Link from 'next/link';
import {Button, Modal as AntdModal, Form, notification} from 'antd';
import { CloseOutlined } from '@ant-design/icons';
import { styled } from 'styled-components';
import { CustomInput, CustomInputPassword } from '../view';
import { getAuth } from '../../actions/auth';
import { setAuthToken } from '../../utils/storage/auth';

type AuthModalProps = {
    open: boolean;
    handleCancel: () => void;
    mode: 'enter' | 'register' | 'reset' | 'finish';
    updateMode: (mode: 'enter' | 'register' | 'reset' | 'finish') => void;
};

const Modal = styled(AntdModal)`
    .ant-modal-content {
        border-radius: 24px !important;
    }
    
    .ant-modal-close {
        height: 64px !important;
        width: 64px !important;
        border-radius: 50% !important;
        background: #fff !important;
        top: -32px !important;
        inset-inline-end: -32px !important;
        
        &:active, &:hover {
            background: #fff !important;
        }
    }
`;

const FilledButton = styled(Button)`
    background: #66A5AD !important;
    font-size: 15px !important;
    border-radius: 8px !important;
    height: 54px !important;
    box-shadow: 0px 2px 4px 0px rgba(102, 165, 173, 0.32) !important;
`;

const OutlinedButton = styled(Button)`
    display: inline-flex !important;
    justify-content: center;
    align-items: center;
    gap: 16px;
    border-color: #66A5AD !important;
    color: #66A5AD !important;
    font-size: 15px !important;
    border-radius: 8px !important;
    height: 54px !important;
    
    span {
        margin-inline-end: 0 !important;
        line-height: 15px !important;
    }
`;

const LinkButton = styled(Button)`
    color: #66A5AD !important;
    font-size: 15px !important;
    height: auto !important;
    padding: 0 !important;
`;

export const AuthModal: FC<AuthModalProps> = ({
    open,
    handleCancel,
    mode,
    updateMode
}) => {
    const [form] = Form.useForm<{ login: string, password: string, confirmPassword: string }>();
    const [isLoading, setIsLoading] = useState<boolean>(false);
    const paths = usePathname().split('/');

    const onAfterClose = () => {
        form.resetFields();
    };

    const onSubmit = () => {
        form.validateFields().then(() => {
            const { login, password } = form.getFieldsValue();
            setIsLoading(true);
            getAuth(login, password, paths[1])
                .then(({ data }) => {
                    if (data.jwtToken) {
                        setAuthToken(data.jwtToken);
                        handleCancel();
                    }
                })
                .catch((error) => {
                    notification.error({
                        message: 'Error',
                        description: error?.response?.data?.errMessage
                    });
                })
                .finally(() => {
                    setIsLoading(false);
                })
        });
    };

    const onValidate = () => {

    };

    return (
        <Modal
            open={open}
            title={undefined}
            onOk={onSubmit}
            onCancel={handleCancel}
            afterClose={onAfterClose}
            footer={false}
            width={498}
            closeIcon={<CloseOutlined style={{ fontSize: 20, color: '#000' }}/>}
        >
            <div className="b-modal__auth__content">
                <div className="b-modal__auth__logo">
                    <img className="" src="/images/logo-auth.svg" alt=""/>
                </div>
                {mode === 'enter' && (
                    <>
                        <Form form={form} autoComplete="off" style={{ display: 'flex', gap: 16, flexDirection: 'column' }}>
                            <Form.Item name="login" rules={[{ required: true }]} noStyle>
                                <CustomInput
                                    size="small"
                                    placeholder="E-mail"
                                />
                            </Form.Item>
                            <Form.Item name="password" rules={[{ required: true }]} noStyle>
                                <CustomInputPassword
                                    size="small"
                                    placeholder="Password"
                                />
                            </Form.Item>
                        </Form>
                        <FilledButton
                            type="primary"
                            onClick={onSubmit}
                            loading={isLoading}
                        >
                            Enter
                        </FilledButton>
                        <OutlinedButton onClick={() => updateMode('register')}>Register</OutlinedButton>
                        <LinkButton
                            type="link"
                            onClick={() => updateMode('reset')}
                        >
                            Forgot password?
                        </LinkButton>
                        <span>or</span>
                        <OutlinedButton
                            icon={<Image src="/images/facebook-logo.png" height={20} width={20} alt="" />}
                        >
                            Facebook account
                        </OutlinedButton>
                        <OutlinedButton
                            icon={<Image src="/images/apple-logo.png" height={22} width={22} alt="" />}
                        >
                            Apple account
                        </OutlinedButton>
                        <OutlinedButton
                            icon={<Image src="/images/google-logo.png" height={20} width={20} alt="" />}
                        >
                            Google account
                        </OutlinedButton>
                    </>
                )}
                {mode === 'register' && (
                    <>
                        <Form form={form} autoComplete="off" style={{ display: 'flex', gap: 16, flexDirection: 'column' }}>
                            <Form.Item name="login" rules={[{ required: true }]} noStyle>
                                <CustomInput
                                    size="small"
                                    placeholder="E-mail"
                                />
                            </Form.Item>
                            <Form.Item name="password" rules={[{ required: true }]} noStyle>
                                <CustomInputPassword
                                    size="small"
                                    placeholder="Password"
                                />
                            </Form.Item>
                            <Form.Item name="confirmPassword" rules={[{ required: true }]} noStyle>
                                <CustomInputPassword
                                    size="small"
                                    placeholder="Confirm password"
                                />
                            </Form.Item>
                        </Form>
                        <FilledButton
                            type="primary"
                        >
                            Register
                        </FilledButton>
                        <OutlinedButton onClick={() => updateMode('enter')}>Enter</OutlinedButton>
                    </>
                )}
                {mode === 'reset' && (
                    <>
                        <Form form={form} autoComplete="off" style={{ display: 'flex', gap: 16, flexDirection: 'column' }}>
                            <Form.Item name="login" rules={[{ required: true }]} noStyle>
                                <CustomInput
                                    size="small"
                                    placeholder="E-mail"
                                />
                            </Form.Item>
                            <Form.Item name="password" rules={[{ required: true }]} noStyle>
                                <CustomInputPassword
                                    size="small"
                                    placeholder="Password"
                                />
                            </Form.Item>
                        </Form>
                        <FilledButton
                            type="primary"
                        >
                            Reset Password
                        </FilledButton>
                        <LinkButton
                            type="link"
                        >
                            Enter
                        </LinkButton>
                    </>
                )}
                {mode === 'finish' && (
                    <>
                        <div className="b-modal__auth__agreement">
                            A link to reset your password has been sent
                            <br />
                            to your email
                        </div>
                        <FilledButton
                            type="primary"
                        >
                            Enter Account
                        </FilledButton>
                    </>
                )}
                <div className="b-modal__auth__agreement">
                    I have read and agree with the terms of the
                    User Agreement, <Link href={'/docs/BBUDDY_privacy_policy_fin.docx' as any}>Privacy Policy</Link>
                </div>
            </div>
        </Modal>
    );
};
